"""Image processing using imagej.
"""

from imageengine import IImage, IImageEngine
from ij import IJ
from ij.plugin import ImageCalculator

class IJImage(IImage):

    def __init__(self, image_engine, ij_image):
        """
        :param IJImageEngine image_engine:
        :param ImagePlus ij_image:
        """
        self.image_engine = image_engine
        self.ij_image = ij_image

    def width(self):
        raise NotImplementedError

    def height(self):
        raise NotImplementedError


class IJImageEngine(IImageEngine):

    def missing(self):
        pass

    def save_as_tiff(self, image, out_file_path):
        IJ.saveAsTiff(image.ij_image, out_file_path)

    def compute_max(self, images_file_path):
        """Computes for each pixel position the maximum at this position in all input images.

        :param list(str) images_file_path:
        :rtype IJmage:
        """
        assert len(images_file_path) > 1
        max_image = IJ.openImage(images_file_path[0])
        print('max_image', max_image)

        for image_file_path in images_file_path[2:-1]:
            other_image = IJ.openImage(image_file_path)
            print('other_image', other_image)
            ic = ImageCalculator()
            ic.run("max", max_image, other_image)
        print('max_image', max_image)
        return max_image
